import { SmtpClient } from 'smtp'
import config from "../email_config.json" assert { type: "json" };

const client = new SmtpClient();

export async function SendVerificationMail(userEmail: string, name: string, companyName: string, verificationToken: string) {
  try {
    await client.connect({
      hostname: config.smtp_server,
      port: config.smtp_port,
      username: config.smtp_username,
      password: config.smtp_password,
    });
  
    await client.send({
      from: "PasswordBox <no-reply@passwordbox.dk>",
      to: userEmail,
      subject: "=?utf-8?B?QmVrcsOmZnQgZGluIGUtbWFpbC1hZHJlc3Nl?=",
      content: `Kære ${name},<br><br>Velkommen til vores interne password manager PasswordBox. For at fuldføre oprettelsesprocessen skal du bekræfte din e-mail-adresse ved at klikke på nedenstående link:<br><br><a href="https://passwordbox.dk/verify?token=${verificationToken}">https://passwordbox.dk/verify?token=${verificationToken}</a><br><br>Hvis du ikke vil tilmeldes vores tjeneste, kan du blot ignorere denne e-mail.<br><br>Med venlig hilsen,<br>PasswordBox<br><br><i>Denne e-mail kan ikke besvares</i>`,
    });
  } catch {
    return error("Kunne ikke sende mail!");
  } finally {
    await client.close();
  }
  return ok(undefined)
}

export async function SendForgotPasswordMail(userEmail: string, name: string, verificationToken: string) {
  try {
    await client.connect({
      hostname: config.smtp_server,
      port: config.smtp_port,
      username: config.smtp_username,
      password: config.smtp_password,
    });
  
    await client.send({
      from: "PasswordBox <no-reply@passwordbox.dk>",
      to: userEmail,
      subject: "PasswordBox - Glemt adgangskode",
      content: `Hej ${name},<br><br><b>Der er blevet anmodet et password reset.</b><br> Klik på følgende link for at nulstille din adgangskode:<br><br><a href="https://passwordbox.dk/verify?token=${verificationToken}">https://passwordbox.dk/verify?token=${verificationToken}</a><br><br>Hvis du ikke har glemt din adgangskode, kan du blot ignorere denne e-mail.<br><br>Med venlig hilsen,<br>PasswordBox<br><br><i>Denne e-mail kan ikke besvares</i>`,
    });
  } catch {
    return error("Kunne ikke sende mail!");
  } finally {
    await client.close();
  }
  return ok(undefined)
}

